#include <Adafruit_NeoPixel.h>

// Which pin on the Arduino is connected to the NeoPixels?
// On a Trinket or Gemma we suggest changing this to 1:
#define LED_PIN    7

// How many NeoPixels are attached to the Arduino?
#define LED_COUNT 60

// Declare our NeoPixel strip object:
Adafruit_NeoPixel strip(LED_COUNT, LED_PIN, NEO_GRB + NEO_KHZ800);
// Argument 1 = Number of pixels in NeoPixel strip
// Argument 2 = Arduino pin number (most are valid)
// Argument 3 = Pixel type flags, add together as needed:
//   NEO_KHZ800  800 KHz bitstream (most NeoPixel products w/WS2812 LEDs)
//   NEO_KHZ400  400 KHz (classic 'v1' (not v2) FLORA pixels, WS2811 drivers)
//   NEO_GRB     Pixels are wired for GRB bitstream (most NeoPixel products)
//   NEO_RGB     Pixels are wired for RGB bitstream (v1 FLORA pixels, not v2)
//   NEO_RGBW    Pixels are wired for RGBW bitstream (NeoPixel RGBW products)

#include <PulseSensorPlayground.h>

const int OUTPUT_TYPE = SERIAL_PLOTTER;


const int PULSE_INPUT = A0;
const int PULSE_BLINK = LED_BUILTIN;
const int PULSE_FADE = 5;
const int THRESHOLD = 550;   // Adjust this number to avoid noise when idle

PulseSensorPlayground pulseSensor;

const int PIN_SPEAKER = 11;    // speaker on pin2 makes a beep with heartbeat

#include "Wire.h"
#include <MPU6050_light.h>

MPU6050 mpu(Wire);
unsigned long timer = 0;
 uint16_t hue = 100;


void setup() {
    Serial.begin(115200);

  // Configure the PulseSensor manager.

  pulseSensor.analogInput(PULSE_INPUT);
  pulseSensor.blinkOnPulse(PULSE_BLINK);
  pulseSensor.fadeOnPulse(PULSE_FADE);

  pulseSensor.setSerial(Serial);
  pulseSensor.setOutputType(OUTPUT_TYPE);
  pulseSensor.setThreshold(THRESHOLD);

  // Now that everything is ready, start reading the PulseSensor signal.
  if (!pulseSensor.begin()) {
   
    for(;;) {
      // Flash the led to show things didn't work.
      digitalWrite(PULSE_BLINK, LOW);
      delay(50);
      digitalWrite(PULSE_BLINK, HIGH);
      delay(50);
    }
  }

  strip.begin();
  strip.show(); // Initialize all pixels to 'off'
  Wire.begin();
  
  byte status = mpu.begin();
  Serial.print(F("MPU6050 status: "));
  Serial.println(status);
  while(status!=0){ } // stop everything if could not connect to MPU6050
  
  Serial.println(F("Calculating offsets, do not move MPU6050"));
  delay(1000);
  // mpu.upsideDownMounting = true; // uncomment this line if the MPU6050 is mounted upside-down
  mpu.calcOffsets(); // gyro and accelero
  Serial.println("Done!\n");
}
void loop()
{
  bool pulse = false;
  strip.show();
  uint32_t red = strip.Color(255,0,0);
  

    if(pulseSensor.UsingHardwareTimer){
    delay(20); 
    pulseSensor.outputSample();
  } else {
    if (pulseSensor.sawNewSample()) {
      if (--pulseSensor.samplesUntilReport == (byte) 0) {
        pulseSensor.samplesUntilReport = SAMPLES_PER_SERIAL_SAMPLE;
        pulseSensor.outputSample();
      }
    }
  }
  if (pulseSensor.sawStartOfBeat()) {
    pulseSensor.outputBeat();
    tone(PIN_SPEAKER,932);
    pulse = true;
  }
  if(pulseSensor.isInsideBeat() == false){
    noTone(PIN_SPEAKER);
  }
  if(pulse == true)
  {
    strip.clear();
    strip.show();
    strip.setPixelColor(11, red);
    strip.setPixelColor(20, red);
    strip.show();
    delay(20);
    strip.setPixelColor(8, red);
    strip.setPixelColor(9, red);
    strip.setPixelColor(10, red);
    strip.setPixelColor(20, red);
    strip.show();
    delay(50);
    strip.fill(red, 0,7);
    strip.fill(red, 12,19);
    strip.show();
    delay(100);
  }
  else
  {
    ColorState();
  }
}


void ColorState()
{
  	Serial.println(hue);
  if(hue > 360)
  {
    hue = 0;
  }
  uint32_t hueshift = strip.gamma32(strip.ColorHSV(hue));
  uint32_t green = strip.Color(0,255,0);
  
  uint32_t white = strip.Color(255,255,255);

  strip.rainbow(0,hue);
  // for(int i = 0; i < LED_COUNT-1; i++)
  // {
  //   	strip.setPixelColor(i,green);
  // }
  strip.show();

  mpu.update();
  
	Serial.print("X : ");
	Serial.print(mpu.getAngleX());
	Serial.print("\tY : ");
	Serial.print(mpu.getAngleY());
	Serial.print("\tZ : ");
	Serial.println(mpu.getAngleZ());

  float angleX = mpu.getAngleX();
  float angleY = mpu.getAngleY();
  //neutral
  if(angleX < 45 &&  angleX > -45)
  {
    strip.setPixelColor(8,white );
    strip.setPixelColor(9, white);
    strip.setPixelColor(10,white);
    strip.setPixelColor(11,white);
    strip.setPixelColor(20,white);


  }
  //tilting left top
  if(angleX < -45 && angleY > 45)
  {
    strip.setPixelColor(0,white);
    strip.setPixelColor(7,white);
    strip.setPixelColor(14,white);
    strip.setPixelColor(15,white);

  }
  //tilting right top
  if(angleY > 45 && angleY > 45)
  {
    strip.setPixelColor(2,white);
    strip.setPixelColor(3,white);
    strip.setPixelColor(12,white);
    strip.setPixelColor(19,white);
  }
  //tilting left bottom
  if(angleY < -45 && angleX < -45)
  {
    strip.setPixelColor(5,white);
    strip.setPixelColor(6,white);
    strip.setPixelColor(7,white);
    strip.setPixelColor(15,white);
    strip.setPixelColor(16,white);
    strip.setPixelColor(17,white);

  }
  //tilting right bottom
  if(angleY < -45 && angleX > 45)
  {
    strip.setPixelColor(3,white);
    strip.setPixelColor(4,white);
    strip.setPixelColor(5,white);
    strip.setPixelColor(17,white);
    strip.setPixelColor(18,white);
    strip.setPixelColor(19,white);


  }
  //tilting top
  if(angleY > 45 && angleX < 45 && angleX > -45)
  {
    strip.setPixelColor(12,white);
    strip.setPixelColor(13,white);
    strip.setPixelColor(14,white);
    strip.setPixelColor(0,white);
    strip.setPixelColor(1,white);
    strip.setPixelColor(2,white);

  }
  //tilting bottom
  if(angleY < -45 && angleX < 45 && angleX > -45)
  {
    strip.setPixelColor(4,white);
    strip.setPixelColor(5,white);
    strip.setPixelColor(6,white);
    strip.setPixelColor(16,white);
    strip.setPixelColor(17,white);
    strip.setPixelColor(18,white);
    strip.setPixelColor(10,white);

  }
  //tilting right
  if(angleX > 45 && angleY < 45 && angleY > -45)
  {
    strip.setPixelColor(3,white);
    strip.setPixelColor(4,white);
    strip.setPixelColor(18,white);
    strip.setPixelColor(19,white);
  }

  //tilting left
  if(angleX < 45 && angleY < 45 && angleY > -45)
  {
    strip.setPixelColor(6,white);
    strip.setPixelColor(7,white);
    strip.setPixelColor(16,white);
    strip.setPixelColor(15,white);
  }

  hue++;

  strip.show();
  delay(10);

}

